==> campsite-2.5.1.tar.gz: campsite/implementation/management/priv/lang/sv/templates.php <==
<?php
regGS("The template '$1' was saved successfully.", "Mallen '$1' sparades framgångsrikt.");
regGS("The template $1 is in use and can not be deleted.", "Mallen $1 används och kan inte raderas.");
regGS("The folder could not be deleted.", "Katalogen kunde inte raderas.");
regGS("The directory must be empty", "Katalogen måste vara tom");
regGS("Create new folder", "Skapa ny katalog");
regGS("Upload template", "Ladda upp mall");
regGS("Creating new folder", "Skapar ny katalog");
regGS("You do not have the right to create new folders.", "Du har inte rätt att skapa nya kataloger.");
regGS("The folder $1 could not be created", "Katalogen $1 kunde inte skapas");
regGS("A file or folder having the name $1 already exists", "Filen eller katalogen med namnet $1 finns redan");
regGS("You do not have the right to delete templates.", "Du har inte rätt att radera mallar.");
regGS("Are you sure you want to delete the folder $1 from $2?", "Är du säker att du vill radera katalogen $1 från $2?");
regGS("Are you sure you want to delete the template $1 from folder $2?", "Är du säker att du vill radera mallen $1 från katalogen $2?");
regGS("Deleting template", "Raderar mall");
regGS("Deleting folder", "Raderar katalog");
regGS("Template $1 was deleted", "Mallen $1 raderades");
regGS("Delete folder", "Radera katalog");
regGS("Folders", "Kataloger");
regGS("No folders.", "Inga kataloger.");
regGS("Files", "Filer");
regGS("No templates.", "Inga mallar.");
regGS("Uploading template", "Laddar upp mall");
regGS("File", "Fil");
regGS("Create new template", "Skapa ny mall");
regGS("Creating new template", "Skapar ny mall");
regGS("Duplicate template", "Duplicera mall");
regGS("Edit template", "Redigera mall");
regGS("The template $1 could not be created.", "Mallen $1 kunde inte skapas.");
regGS("Template $1 was changed", "Mallen $1 ändrades");
regGS("New template $1 was created", "Ny mall $1 skapades");
regGS("Template $1 was duplicated into $2", "Mallen $1 duplicerades till $2");
regGS("Template charset", "Mallteckenuppsättning");
regGS("Select a language/character set", "Välj ett språk/teckenuppsättning");
regGS("All languages", "Alla språk");
regGS("You do not have the right to modify templates.", "Du har inte rätt att redigera mallar.");
regGS("Invalid template file $1", "Ogiltig mallfil $1");
regGS("You do not have the right to create folders.", "Du har inte rätt att skapa kataloger.");
regGS("You do not have the right to upload templates.", "Du har inte rätt att ladda upp mallar.");
regGS("You do not have the right to create templates.", "Du har inte rätt att skapa mallar.");
regGS("Duplicate file", "Duplicera fil");
regGS("Delete file", "Radera fil");
regGS("Unable to save the template '$1' to the path '$2'.", "Kunde inte spara mallen '$1' i sökvägen '$2'.");
regGS("Please check if the user '$1' has permission to write in this directory.", "Var god kontrollera om användaren '$1' har rätt att skriva i den här katalogen.");
regGS("Unable to delete the template '$1' in the path '$2'.", "Kunde inte skapa mallen '$1' i sökvägen '$2'.");
?>

==> campsite-2.6.6.tar.gz: campsite/implementation/management/priv/lang/sv/templates.php <==
<?php 
regGS("Template ID:", "");
regGS("Template ID", "");
regGS("Template $1 no longer exists!", "");
regGS("New template $1 created", "");
regGS("If the file you specified is a text file, you can convert its character set using the dropdown below.", "");
regGS("Directory $1 was deleted", "");
regGS("Directory $1 created.", "");
regGS("You must select a file to upload.", "");
regGS("You can only replace a file with a file of the same type.  The original file is of type \"$1\", and the file you uploaded was of type \"$2\".", "");
regGS("Unable to save the file '$1' to the path '$2'.", "");
regGS("Replace file:", "");
regGS("Replace", "");
regGS("File \"$1\" uploaded.", "");
regGS("File \"$1\" replaced.", "");
regGS("The folder name can't be '..' or '.'", "");
regGS("The template '$1' was saved successfully.", "Mallen '$1' sparades framgångsrikt.");
regGS("The template $1 is in use and can not be deleted.", "Mallen $1 används och kan inte raderas.");
regGS("Create new folder", "Skapa ny katalog");
regGS("Upload template", "Ladda upp mall");
regGS("You do not have the right to create new folders.", "Du har inte rätt att skapa nya kataloger.");
regGS("A file or folder having the name $1 already exists", "Filen eller katalogen med namnet $1 finns redan");
regGS("You do not have the right to delete templates.", "Du har inte rätt att radera mallar.");
regGS("Are you sure you want to delete the folder $1 from $2?", "Är du säker att du vill radera katalogen $1 från $2?");
regGS("Are you sure you want to delete the template $1 from folder $2?", "Är du säker att du vill radera mallen $1 från katalogen $2?");
regGS("Template $1 was deleted", "Mallen $1 raderades");
regGS("Delete folder", "Radera katalog");
regGS("Folders", "Kataloger");
regGS("No folders.", "Inga kataloger.");
regGS("Files", "Filer");
regGS("No templates.", "Inga mallar.");
regGS("File", "Fil");
regGS("Create new template", "Skapa ny mall");
regGS("Duplicate template", "Duplicera mall");
regGS("Edit template", "Redigera mall");
regGS("The template $1 could not be created.", "Mallen $1 kunde inte skapas.");
regGS("Template $1 was changed", "Mallen $1 ändrades");
regGS("Template $1 was duplicated into $2", "Mallen $1 duplicerades till $2");
regGS("Template charset", "Mallteckenuppsättning");
regGS("Select a language/character set", "Välj ett språk/teckenuppsättning");
regGS("All languages", "Alla språk");
regGS("You do not have the right to modify templates.", "Du har inte rätt att redigera mallar.");
regGS("Invalid template file $1", "Ogiltig mallfil $1");
regGS("You do not have the right to create folders.", "Du har inte rätt att skapa kataloger.");
regGS("You do not have the right to upload templates.", "Du har inte rätt att ladda upp mallar.");
regGS("You do not have the right to create templates.", "Du har inte rätt att skapa mallar.");
regGS("Duplicate file", "Duplicera fil");
regGS("Delete file", "Radera fil");
regGS("Please check if the user '$1' has permission to write in this directory.", "Var god kontrollera om användaren '$1' har rätt att skriva i den här katalogen.");
?>
